@@ -21,7 +21,7 @@
 #endif
 
 #ifdef LZLIB_COMPAT
-/**************** lzlib compatibilty **********************************/
+/**************** lzlib compatibility **********************************/
 /* Taken from https://raw.githubusercontent.com/LuaDist/lzlib/93b88e931ffa7cd0a52a972b6b26d37628f479f3/lzlib.c */
 
 /************************************************************************
@@ -51,7 +51,7 @@
 
 /*
 ** =========================================================================
-** compile time options wich determine available functionality
+** compile time options which determine available functionality
 ** =========================================================================
 */
 
@@ -613,16 +613,16 @@ static int lzstream_decompress(lua_State *L) {
 
 static int lzstream_readline(lua_State *L) {
     lz_stream *s;
-    int sucess;
+    int success;
 
     s = lzstream_check(L, lua_upvalueindex(1), LZ_INFLATE);
-    sucess = lz_read_line(L, s);
+    success = lz_read_line(L, s);
 
     if (s->error != Z_OK) {
         return lz_pushresult(L, s);
     }
 
-    if (sucess) {
+    if (success) {
         return 1;
     } else {
         /* EOF */
@@ -924,7 +924,7 @@ static int lz_assert(lua_State *L, int result, const z_stream* stream, const cha
  *
  * if no params, terminates the stream (as if we got empty string and Z_FINISH).
  */
-static int lz_filter_impl(lua_State *L, int (*filter)(z_streamp, int), int (*end)(z_streamp), char* name) {
+static int lz_filter_impl(lua_State *L, int (*filter)(z_streamp, int), int (*end)(z_streamp), const char* name) {
     int flush = Z_NO_FLUSH, result;
     z_stream* stream;
     luaL_Buffer buff;
@@ -1191,8 +1191,8 @@ static int lz_checksum(lua_State *L) {
 }
 
 static int lz_checksum_new(lua_State *L, checksum_t checksum, checksum_combine_t combine) {
-    lua_pushlightuserdata(L, checksum);
-    lua_pushlightuserdata(L, combine);
+    lua_pushlightuserdata(L, (void *)checksum);
+    lua_pushlightuserdata(L, (void *)combine);
     lua_pushnumber(L, checksum(0L, Z_NULL, 0));
     lua_pushnumber(L, 0);
     lua_pushcclosure(L, lz_checksum, 4);
@@ -1267,7 +1267,7 @@ LUALIB_API int luaopen_zlib(lua_State * const L) {
 
     SETLITERAL("_COPYRIGHT", "Copyright (c) 2009-2016 Brian Maher");
     SETLITERAL("_DESCRIPTION", "Simple streaming interface to the zlib library");
-    SETLITERAL("_VERSION", "lua-zlib $Id: da57e91a3a58c7f514e2058feccea7a7b42db5e2 $  (tag: v1.2)");
+    SETLITERAL("_VERSION", "lua-zlib $Id: 7680c9e2cb89fde21519c1b81b7ff740bd2ca9e8 $");
 
     /* Expose this to lua so we can do a test: */
     SETINT("_TEST_BUFSIZ", LUAL_BUFFERSIZE);
